summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmplaneedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmplaneedit.h')
-rw-r--r--kpovmodeler/pmplaneedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmplaneedit.h b/kpovmodeler/pmplaneedit.h
index 0b4c3f3f..33d01e64 100644
--- a/kpovmodeler/pmplaneedit.h
+++ b/kpovmodeler/pmplaneedit.h
@@ -38,9 +38,9 @@ class PMPlaneEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMPlaneEdit with tqparent and name
*/
- PMPlaneEdit( TQWidget* tqparent, const char* name = 0 );
+ PMPlaneEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,9 +38,9 @@ class PMPlaneEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMPlaneEdit with tqparent and name
+ * Creates a PMPlaneEdit with parent and name
*/